
/* Generated data (by glib-mkenums) */

#include "griptypebuiltins.h"
/* enumerations from "gripgesturemanager.h" */
#include "gripgesturemanager.h"
GType
grip_gesture_type_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { GRIP_GESTURE_DRAG, "GRIP_GESTURE_DRAG", "drag" },
        { GRIP_GESTURE_PINCH, "GRIP_GESTURE_PINCH", "pinch" },
        { GRIP_GESTURE_ROTATE, "GRIP_GESTURE_ROTATE", "rotate" },
        { GRIP_GESTURE_TAP, "GRIP_GESTURE_TAP", "tap" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("GripGestureType"), values);
    }
  return enum_type_id;
}
GType
grip_time_type_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { GRIP_TIME_START, "GRIP_TIME_START", "start" },
        { GRIP_TIME_UPDATE, "GRIP_TIME_UPDATE", "update" },
        { GRIP_TIME_END, "GRIP_TIME_END", "end" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("GripTimeType"), values);
    }
  return enum_type_id;
}
/* enumerations from "gripinputdevice.h" */
#include "gripinputdevice.h"
GType
grip_device_type_get_type(void) {
  static GType enum_type_id = 0;
  if (G_UNLIKELY (!enum_type_id))
    {
      static const GEnumValue values[] = {
        { GRIP_DEVICE_TOUCHSCREEN, "GRIP_DEVICE_TOUCHSCREEN", "touchscreen" },
        { GRIP_DEVICE_TOUCHPAD, "GRIP_DEVICE_TOUCHPAD", "touchpad" },
        { GRIP_DEVICE_INDEPENDENT, "GRIP_DEVICE_INDEPENDENT", "independent" },
        { 0, NULL, NULL }
      };
      enum_type_id = g_enum_register_static (g_intern_static_string ("GripDeviceType"), values);
    }
  return enum_type_id;
}

/* Generated data ends here */

